==> wiki3_5_5.zip: wiki3_5_5/plugin/comment/CommentHandler.pm <==
############################################################
# 
# Commentץ饰Υϥɥ顣
# 
############################################################
package plugin::comment::CommentHandler;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# Ȥν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $name    = $cgi->param("name");
	my $message = $cgi->param("message");
	my $count   = $cgi->param("count");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name eq ""){
		$name = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	if($page ne "" && $message ne "" && $count ne ""){
		
		my @lines = split(/\n/,$wiki->get_page($page));
		my $flag       = 0;
		my $form_count = 1;
		my $content    = "";
		
		foreach(@lines){
			# ξ
			if($option eq "reverse"){
				$content = $content.$_."\n";
				if(/^{{comment\s*.*}}$/ && $flag==0){
					if($form_count==$count){
						$content = $content."*$message - $name (".Util::format_date(time()).")\n";
						$flag = 1;
					} else {
						$form_count++;
					}
				}
			# ڡɲäξ
			} elsif($option eq "tail"){
				$content = $content.$_."\n";
				
			# ƽξ
			} else {
				if(/^{{comment\s*.*}}$/ && $flag==0){
					if($form_count==$count){
						$content = $content."*$message - $name (".Util::format_date(time()).")\n";
						$flag = 1;
					} else {
						$form_count++;
					}
				}
				$content = $content.$_."\n";
			}
		}
		
		# ڡɲäξϺǸɲ
		if($option eq "tail"){
			$content = $content."*$message - $name (".Util::format_date(time()).")\n";
			$flag = 1;
		}
		
		if($flag==1){
			$wiki->save_page($page,$content);
		}
	}
	
	# Υڡ˥쥯
	$wiki->redirect($page);
}

1;

==> wiki3_5_6dev1.zip: wiki3_5_6dev1/plugin/comment/CommentHandler.pm <==
############################################################
# 
# Commentץ饰Υϥɥ顣
# 
############################################################
package plugin::comment::CommentHandler;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# Ȥν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $name    = $cgi->param("name");
	my $message = $cgi->param("message");
	my $count   = $cgi->param("count");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name eq ""){
		$name = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	# եޥåȥץ饰ؤб
	my $format = $wiki->get_edit_format();
	$name    = $wiki->convert_to_fswiki($name   ,$format,1);
	$message = $wiki->convert_to_fswiki($message,$format,1);
	
	if($page ne "" && $message ne "" && $count ne ""){
		
		my @lines = split(/\n/,$wiki->get_page($page));
		my $flag       = 0;
		my $form_count = 1;
		my $content    = "";
		
		foreach(@lines){
			# ξ
			if($option eq "reverse"){
				$content = $content.$_."\n";
				if(/^{{comment\s*.*}}$/ && $flag==0){
					if($form_count==$count){
						$content = $content."*$message - $name (".Util::format_date(time()).")\n";
						$flag = 1;
					} else {
						$form_count++;
					}
				}
			# ڡɲäξ
			} elsif($option eq "tail"){
				$content = $content.$_."\n";
				
			# ƽξ
			} else {
				if(/^{{comment\s*.*}}$/ && $flag==0){
					if($form_count==$count){
						$content = $content."*$message - $name (".Util::format_date(time()).")\n";
						$flag = 1;
					} else {
						$form_count++;
					}
				}
				$content = $content.$_."\n";
			}
		}
		
		# ڡɲäξϺǸɲ
		if($option eq "tail"){
			$content = $content."*$message - $name (".Util::format_date(time()).")\n";
			$flag = 1;
		}
		
		if($flag==1){
			$wiki->save_page($page,$content);
		}
	}
	
	# Υڡ˥쥯
	$wiki->redirect($page);
}

1;
